netapp_ontap.models.vdi_on_nas_desktops API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.vdi_on_nas_desktops`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VdiOnNasDesktopsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VdiOnNasDesktops object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `count GET POST PATCH`

    The number of desktops to support.

  `size GET POST`

    The size of the desktops. Usage: {<integer>[KB|MB|GB|TB|PB]}

  `storage_service GET POST PATCH`

    The storage_service field of the vdi_on_nas_desktops.